
def simplechat_dictionary_run(input_charecter_dictionary, input_dictionary_dictionary):
    while True:
        input_question_dictionary = input(input_charecter_dictionary)
        print(input_dictionary_dictionary[input_question_dictionary])